#
# spec file for package terraform-provider-random
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-random
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    random

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-random
Version:        3.0.0
Release:        6.3.1
Summary:        Terraform Random provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-random
Source:         %{repo}-%{version}.tar.xz
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
Requires:       terraform >= 0.12.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang(API) >= 1.14
BuildRequires:  golang-packaging
BuildRequires:  xz
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a Random provider for Terraform.

%prep
%setup -q -n %{repo}-%{version}

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Nov 11 2020 adrian.glaubitz@suse.com
- Add symbolic link to comply with new filesystem layout for local provider copies
- Define and use common Go spec file variables
* Tue Oct 20 2020 adrian.glaubitz@suse.com
- Update to version 3.0.0:
  * Update CHANGELOG.md
  * add .tfproto5 file for releases
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * update Go version
  * remove outdated website targets
  * use tfexec for test binary
  * SDK v2.0.3
  * remove test for deprecated attribute
  * Add descriptions
  * Match scaffolding provider structure
  * Remove deprecated attribute
  * SDKv2 upgrade
  * Cleanup after v2.3.0 release
* Mon Aug 10 2020 adrian.glaubitz@suse.com
- Update to version 2.3.0:
  * github.com/hashicorp/terraform-plugin-sdk@v1.11.0
  * restore hashibot behaviors after org transfer
  * Fix vendoring and bump Go
  * Random String and Password Import
  * fix env vars
  * enable go modules and vendoring in travis
  * Travis: run acceptance tests
  * Travis: install terraform
  * opt in to new binary test driver
  * upgrade to plugin SDK v1.7.0
  * Update password.html.md
* Fri Feb  7 2020 rjschwei@suse.com
- Create symlink for terraform to recognize the provider. See
  https://www.terraform.io/docs/extend/how-terraform-works.html#plugin-locations
* Wed Feb  5 2020 adrian.glaubitz@suse.com
- Initial build
  + Version 2.2.1
